@@ -2,13 +2,13 @@
 # 3rd Party libraries
 import graphene
 # Standard/core python libraries
-# Our custom libraries
-from .users.schema import UserQueries
+# Our custom libraries (Managed by SPRINGLABS_DJANGO)
+from .users.schema import ExampleDjangoQueries
 
 # QUERY EXPOSE TO SCHEMA GRPAHENE
 
 
-class Query(UserQueries, graphene.ObjectType):
+class Query(ExampleDjangoQueries, graphene.ObjectType):
     pass
 
 
