@@ -17,15 +17,15 @@ from core.documentation import (
 
 # PUBLIC URLS name_version
 urls_name_version_0 = [
-    url(r'^name_version/', include(public_urls)),
+    url(r'^v1/', include(public_urls)),
 ]
 
 # DOCUMENTATION URLS name_version
 doc_patterns = [
     url(r'^', include_docs_urls(title=title_name_version_0,
-                                patterns=urls_name_version_0,
-                                description=description_name_version_0,
-                                namespace=namespace_name_version_0)),
+        patterns=urls_name_version_0,
+        description=description_name_version_0,
+        namespace=namespace_name_version_0)),
 ] + static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
 
 # GENERAL URLS name_version
